@@ -329,7 +329,7 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 
 	if (strcmp (path, "user") != 0 &&
 	    !gyrus_admin_mailbox_exists (admin, path)) {
-		*error = g_strdup_printf (_("Parent mailbox '%s' does not exists. "
+		*error = g_strdup_printf (_("Parent mailbox '%s' does not exist. "
 					    "Please refresh the mailboxes list and try again."),
 					  path);
 		return FALSE;
