@@ -229,6 +229,15 @@ GyrusImapStatus gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message,
 */
 GIOError gyrus_admin_write_channel (GyrusAdmin *admin, gchar *message);
 
+/**
+   Parses a LIST server message and get the mailbox name from it.
+
+   @msg: The message returned by the server.
+
+   Returns: a newly allocated mailbox name.
+*/
+gchar *
+gyrus_admin_get_mailbox_from_list_message (gchar *msg);
 
 #endif /* GYRUS_ADMIN_H */
 
