@@ -35,10 +35,17 @@ struct _GyrusSession
 	guint port;
 	gchar *user;
 	gchar *passwd;
+	gchar *sep_char;
+	gboolean usetls;
 };
 
+/** Callback to load the interface of the sessions system.
+*/
 void 
-gyrus_session_show_sessions (GtkWidget *widget, gpointer user_data);
+gyrus_session_show_sessions (GtkWidget *widget G_GNUC_UNUSED, 
+			     gpointer user_data);
+
+/** Frees the memory used for a GyrusSession object. */
 void
 gyrus_session_free (GyrusSession *session);
 
